@@ -2,11 +2,13 @@
 
 from django.conf.urls import url
 
-from scientific_survey.views import ConfirmView, IndexView, SurveyCompleted, SurveyDetail
+from scientific_survey.views import ConfirmView, IndexView, SurveyCompleted, SurveyDetail, survey_error, survey_full
 from scientific_survey.views.import_view import import_from_json
 
 urlpatterns = [
     url(r"^$", IndexView.as_view(), name="survey-list"),
+    url(r"^error", survey_error, name="survey-error"),
+    url(r"^full", survey_full, name="survey-full"),
     url(r"^(?P<id>\d+)/", SurveyDetail.as_view(), name="survey-detail"),
     url(r"^(?P<id>\d+)/completed/", SurveyCompleted.as_view(), name="survey-completed"),
     url(r"^(?P<id>\d+)-(?P<step>\d+)-(?P<seed>\d+)/", SurveyDetail.as_view(), name="survey-detail-step"),
